@@ -17,7 +17,7 @@ class DingDingPlugin(NotificationPlugin):
     """
     author = 'dreamerldq'
     author_url = 'https://github.com/dreamerldq/sentry-dingding-format'
-    version = '1.1.3'
+    version = '1.1.4'
     description = 'Send project error counts to DingDing .'
     resource_links = [
         ('Source', 'https://github.com/dreamerldq/sentry-dingding-format'),
@@ -61,8 +61,8 @@ class DingDingPlugin(NotificationPlugin):
 
         count = self.getGroupCount(group.id)
 
-        if(int(count)>=2):
-            return
+        # if(int(count)>=2):
+        #     return
         
 
         access_token = self.get_option('access_token', group.project)
@@ -73,13 +73,14 @@ class DingDingPlugin(NotificationPlugin):
             "msgtype": "markdown",
             "markdown": {
                 "title": title,
-                "text": u"#### {title} \n\n > {message} \n\n > 设备:{device} \n\n > 责任人:{name} \n\n > UID:{uid} \n\n > Count:{count} \n\n > {path} \n\n [详细信息]({url})".format(
+                "text": u"#### {title} \n\n > {message} \n\n > 设备:{device} \n\n > 责任人:{name} \n\n > UID:{uid} \n\n > Count:{count} \n\n > GROUPID:{groupId} \n\n >  {path} \n\n [详细信息]({url})".format(
                     title=title,
                     device=event.get_tag('device'),
                     uid=event.get_tag('uid'),
                     path=event.get_tag('url'),
                     name=event.get_tag('name'),
                     count=count,
+                    groupId=group.id,
                     message=event.title or event.message,
                     url=u"{}events/{}/".format(group.get_absolute_url(), event.event_id),
                 )
